==> alg-feature-panghangyi-20220727.120457-1-sources.jar: cn/com/duiba/nezha/alg/feature/vo/AdxFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.Map;


/**
 * ADX特征对象
 * @date 2022/3/25
 */
@Data
public class AdxFeatureDo implements Serializable {
    private static final long serialVersionUID = 6695201251295150673L;

    //推广组
    private Long groupId; // 推广组ID f1010010
    private Integer adxType; // 平台类型 f1010020
//    private String cat; // 推广组对应类别 f1010030
//    private String tuiaCat; // 推啊平台的推广组对应类别(标准) f1010031
//    private String sectionCat; // 推广组当前部分的类别 f1010040
//    private String tuiaSectionCat; // 推啊平台的推广组当前部分的类别(标准) f1010041
//    private String keywords; // 推广组关键词 f1010050


    //资源位
    private Long resourceId; // 资源位ID f2010010
    private Integer advertType; // 广告类型 f2010020
    private Integer posType; // 广告位类型 f2010030
    //    private Integer posStyle; // 广告位样式 f2010040
    private String specCode; // 广告类型编码 f2010050


    //媒体广告位ID
    private String appSlotId;//f2010060

    private String externalAppId;//联盟媒体id f2010061
    private String externalAppTrade;//联盟媒体行业id f2010062
//    private String adType;//广告类型 f2010063


    //创意特征
    private Long ideaId; // 创意ID f3010010
    //    private String buttonText; // 按钮文字 f3010020
//    private Integer iconH; // 创意图标高 f3010030
//    private Integer iconW; // 创意图标宽 f3010040
//    private Integer mjPicType; // 规格类型 f3010050
    private Integer ideaPicH1; // 创意图片高1 f3010060
    private Integer ideaPicW1; // 创意图片宽1 f3010070
    //    private Integer ideaPicH2; // 创意图片高2 f3010080
//    private Integer ideaPicW2; // 创意图片宽2 f3010090
//    private Integer ideaPicH3; // 创意图片高3 f3010100
//    private Integer ideaPicW3; // 创意图片宽3 f3010110
//    private Integer ideaPicNum; // 创意图片个数 f3010120
//    private String styleStandard; // 广告样式规格 f3010130
    private Integer ideaType; //互动创意类型(0-普通静态创意，1-动态创意) f3010140

    //创意素材标签特征
    private Long materialId; //素材ID
    private Integer pictureType; //素材图片类型（1=图片 3=视频）f3030000
    private List<AdxIdeaMaterialDo> pictureMaterialDo; //图片素材特征
    private List<AdxIdeaMaterialDo> videoMaterialDo; //视频素材特征

//    private String materialIndustryTag; // 素材行业标签
//    private String slotType; // 广告位性质
//    private String prizeElement; // 奖品元素
//    private String designColor; // 设计色调
//    private String designStyle; // 设计风格
//    private String textElement; // 文案元素
//    private String activityTool; // 活动工具


    private Long ideaUnitId; //创意素材ID

    //创意+分媒体行为特征
    private Long ideaAppExpCntDay; //创意+百度appId 当天曝光次数 f3060011
    private Long ideaAppClickCntDay; //创意+百度appId 当天点击次数 f3060012
    private Long ideaAppAdCostDay; //创意+百度appId 当天广告消耗	 f3060013

    private Long ideaAppLaunchCntDay; //创意+百度appId 当天发券次数 f3060016
    private Long ideaAppAdClickCntDay; //创意+百度appId 当天券点击次数 f3060017


    //上下文
    private String ua; // ua f4010010
    private String ip; // ip f4010020

    /**
     * IP应用场景 f4010021
     */
    private String ipUsageType;

    private Long areaCode; // 地域 f4010030
    //    private Integer deviceType; // 设备类型 f4010040
//    private Integer tuiaDeviceType; // 推啊平台的设备类型(标准) f4010041
    private String make; // 设备厂商 f4010050
    private String model; // 设备型号 f4010060
    private String os; // 操作系统 f4010070
    private String osv; // 操作系统版本
    private String carrier; // 运营商 f4010080
    //    private Integer connectionType; // 联网方式 f4010090
    private Integer tuiaConnectionType; // 推啊平台的联网方式(标准) f4010091
    //    private Float lat; // 纬度 f4010100
//    private Float lon; // 经度 f4010110
    private Long currentCreatTime; // 参与当前竞价请求的创建时间(时间戳) f4010120


    //用户行为
    private String gender; // 性别 f5010010
    //    private String interestKeyWords; // 用户兴趣 f5010020
    private String yob; // 出生年月 f5010030
    //    private Map<Long, Object> expTimeMap; // 该创意+设备号的当天累计曝光次数 f5010040
    private String imei; // 设备号 f5010050
    private Integer deviceRequestLevel; // 设备请求次数（1-当天首次进入 2-当天第二次进入 3-当天大于等于第三次进入）

    private Map<String, Long> imeiDayBidTimes; // 设备号 当天竞价次数  f5010060
    private Map<String, Long> imeiDayExpTimes; // 设备号 当天曝光次数  f5010070
    private Map<String, Long> resoDayBidTimes; // 资源位id+设备号 当天竞价次数  f5010080
    private Map<String, Long> resoDayExpTimes; // 资源位id+设备号 当天曝光次数  f5010090

    private String newSex; // (爱奇艺)性别标签 f5010100

    //上下文-新增
    private String appName; // 应用名称 f6010010
    private String appBundle; // 包名 f6010020
    //    private String appPageCat; // 应用当前页类型 f6010030
//    private Integer appPaid; // 0-免费 1-付费 f6010040
//    private String geoCountry; // 设备位置信息-国家 f6010050
//    private String geoRegion; // 设备位置信息-地区 f6010060
    private String geoCity; //设备位置信息-城市 f6010070
    //    private Integer geoType; //设备位置信息-定位类型 f6010080
    private String tagId; // adx资源位，竞价广告位ID（adx方） f6010090
    private Integer tagIndex; // adx资源位，竞价广告位顺序索引（adx方） f6010100
    private String pos; // 广告位位置，第几屏
    private String matType; // 流量需要的素材类型，图片,视频,原生之类的
//    private String appIndustryId; //app所属行业id f6010110

    //资源位+分媒体行为特征
    private Long resoAppExpCntDay; //资源位+百度appId  近1h曝光次数 f6060011
    private Long resoAppClickCntDay; //资源位+百度appId  近1h点击次数 f6060012
    private Long resoAppAdCostDay; //资源位+百度appId  近1h广告消耗 f6060013

    //资源位历史行为特征
    private Long resoExpDay; // 资源位 当天 入口素材曝光次数 f3016010
    private Long resoActAccDay; // 资源位 当天 活动访问次数 f3016011
    private Long resoActJoinDay; // 资源位 当天 活动参与次数 f3016012
    private Long resoCoupClkpvDay; // 资源位 当天 券计费点击次数 f3016013
    private Long resoExp1Day; // 资源位 历史1天 入口素材曝光次数 f3016014
    private Long resoActAcc1Day; // 资源位 历史1天 活动访问次数 f3016015
    private Long resoActJoin1Day; // 资源位 历史1天 活动参与次数 f3016016
    private Long resoCoupClkpv1Day; // 资源位 历史1天 券计费点击次数 f3016017
    private Long resoExp7Day; // 资源位 历史7天 入口素材曝光次数 f3016018
    private Long resoActAcc7Day; // 资源位 历史7天 活动访问次数 f3016019
    private Long resoActJoin7Day; // 资源位 历史7天 活动参与次数 f3016020
    private Long resoCoupClkpv7Day; // 资源位 历史7天 券计费点击次数 f3016021
    private Long resoExp14Day; // 资源位 历史14天 入口素材曝光次数 f3016022
    private Long resoActAcc14Day; // 资源位 历史14天 活动访问次数 f3016023
    private Long resoActJoin14Day; // 资源位 历史14天 活动参与次数 f3016024
    private Long resoCoupClkpv14Day; // 资源位 历史14天 券计费点击次数 f3016025




    // DMP数据引入
    private String userTagsList; //f7010010, 用户标签列表
    private String appList; //f7020010, app安装列表
    //    private String messageNameList; //f7030010, 短信签名列表
    //dmp特征加工
    private DmpFeature dmpFeature;

    //adx用户素材行为数据
//    private String expDayMaterials; //用户当天曝光的素材序列（曝光降序）TOP30
//    private String clickDayMaterials; //用户当天点击的素材序列（点击降序）TOP30
//    private String expWeekMaterials; //用户近7天曝光的素材序列 (曝光降序) TOP30
//    private String clickWeekMaterials; //用户近7天点击的素材序列（点击降序）TOP30
//    private String resoExpDayMaterials; //用户+资源位，当天曝光的素材序列（曝光降序）TOP30
//    private String resoClickDayMaterials; //用户+资源位，当天点击的素材序列（点击降序）TOP30
//    private Long lastExpMaterialId; //用户+资源位，上次曝光的素材id
//    private Long lastClickMaterialId; //用户+资源位，上次点击的素材id


    //adx特定数据特征
//    private AiQiYiFeature aiQiYiFeature;//爱奇艺数据特征
    private MgTvFeature mgTvFeature;//芒果tv数据特征
//    private BaiDuFeature baiDuFeature;//百度联盟数据特征

    //PD特征
    private Integer pmpType; //0-RTB 1-PD 2-PDB f3020000
    private Long dealId; // PD deal ID f3020010
    private Long price; // PD ldeal出价 f3020020

    //创意+活动特征
    private Long ideaActAccCntDay;   //创意 当天活动访问次数 f3010141
    private Long ideaActJoinCntDay;   //创意 当天活动参与次数 f3010142
    private Long ideaActAccCntWeek;   //创意 一周活动访问次数 f3010143
    private Long ideaActJoinCntWeek;   //创意 一周活动参与次数 f3010144


    //素材行为数据
    private Long matAdxExpDay;  //创意素材 当天入口曝光次数 f3040010
    private Long matAdxClickDay;    //创意素材 当天入口点击次数 f3040020

//    private Long matAdxExp1d; //素材 历史1天 入口曝光次数 f3040030
//    private Long matAdxClick1d; //素材 历史1天 入口点击次数 f3040040
//    private Long matAdxExp7d; //素材 历史7天 入口曝光次数 f3040050
//    private Long matAdxClick7d; //素材 历史7天 入口点击次数 f3040060
//    private Long matAdxExp14d; //素材 历史14天 入口曝光次数 f3040070
//    private Long matAdxClick14d; //素材 历史14天 入口曝光次数 f3040080

    private Long matActReqDay;   //素材 当天活动访问次数
    private Long matActJoinDay;   //素材 当天活动参与次数
    private Long matAdvertExpDay;   //素材 当天广告曝光次数
    private Long matAdvertClkDay;   //素材 当天广告点击次数


    private Long matActReq7d;   //素材 7天活动访问次数
    private Long matActJoin7d;   //素材 7天活动参与次数
    private Long matAdvertExp7d;   //素材 7天广告曝光次数
    private Long matAdvertClk7d;   //素材 7天广告点击次数

    private Long matActReq28d;   //素材 28天活动访问次数
    private Long matActJoin28d;   //素材 28天活动参与次数
    private Long matAdvertExp28d;   //素材 28天广告曝光次数
    private Long matAdvertClk28d;   //素材 28天广告点击次数

    private Long matResoActReqDay;   //素材+资源位 当天活动访问次数
    private Long matResoActJoinDay;   //素材+资源位 当天活动参与次数
    private Long matResoAdvertExpDay;   //素材+资源位 当天广告曝光次数
    private Long matResoAdvertClkDay;   //素材+资源位 当天广告点击次数

    private Long matResoActReq7d;   //素材+资源位 7天活动访问次数
    private Long matResoActJoin7d;   //素材+资源位 7天活动参与次数
    private Long matResoAdvertExp7d;   //素材+资源位 7天广告曝光次数
    private Long matResoAdvertClk7d;   //素材+资源位 7天广告点击次数

    private Long matResoActReq28d;   //素材+资源位 28天活动访问次数
    private Long matResoActJoin28d;   //素材+资源位 28天活动参与次数
    private Long matResoAdvertExp28d;   //素材+资源位 28天广告曝光次数
    private Long matResoAdvertClk28d;   //素材+资源位 28天广告点击次数

//    private Map<Long, Long> matAdvertTradeExp7d; //素材 7天内不同广告行业券曝光次数
//    private Map<Long, Long> matAdvertTradeClk7d; //素材 7天内不同广告行业券点击次数
//    private Map<Long, Long> matAdvertTradeExp28d; //素材 28天内不同广告行业券曝光次数
//    private Map<Long, Long> matAdvertTradeClk28d; //素材 28天内不同广告行业券点击次数
//
//    private Map<Long, Long> matResoAdvertTradeExp7d; //素材+资源位 7天内不同广告行业券曝光次数
//    private Map<Long, Long> matResoAdvertTradeClk7d; //素材+资源位 7天内不同广告行业券点击次数
//    private Map<Long, Long> matResoAdvertTradeExp28d; //素材+资源位 28天内不同广告行业券曝光次数
//    private Map<Long, Long> matResoAdvertTradeClk28d; //素材+资源位 28天内不同广告行业券点击次数

    //活动+创意行为数据
    private Map<Long, Long> actIdeaActAccCntDay;    //活动+创意 当天活动访问数据
    private Map<Long, Long> actIdeaActJoinCntDay;    //活动+创意 当天活动参与数据
    private Map<Long, Long> actIdeaActAccCntWeek;    //活动+创意 一周活动访问数据
    private Map<Long, Long> actIdeaActJoinCntWeek;    //活动+创意 一周活动参与数据

    //计划维度、2d时间维度统计数据
    private Long idea2dExp;
    private Long idea2dClick;
    private Long idea2dFlcClick;


    //rta用户打分模型特征
    private RtaFeatureDo rtaFeatureDo;
}

==> alg-feature-panghangyi-20220728.062114-3-sources.jar: cn/com/duiba/nezha/alg/feature/vo/AdxFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.Map;


/**
 * ADX特征对象
 * @date 2022/3/25
 */
@Data
public class AdxFeatureDo implements Serializable {
    private static final long serialVersionUID = 6695201251295150673L;

    //推广组
    private Long groupId; // 推广组ID f1010010
    private Integer adxType; // 平台类型 f1010020
//    private String cat; // 推广组对应类别 f1010030
//    private String tuiaCat; // 推啊平台的推广组对应类别(标准) f1010031
//    private String sectionCat; // 推广组当前部分的类别 f1010040
//    private String tuiaSectionCat; // 推啊平台的推广组当前部分的类别(标准) f1010041
//    private String keywords; // 推广组关键词 f1010050


    //资源位
    private Long resourceId; // 资源位ID f2010010
    private Integer advertType; // 广告类型 f2010020
    private Integer posType; // 广告位类型 f2010030
    //    private Integer posStyle; // 广告位样式 f2010040
    private String specCode; // 广告类型编码 f2010050


    //媒体广告位ID
    private String appSlotId;//f2010060

    private String externalAppId;//联盟媒体id f2010061
    private String externalAppTrade;//联盟媒体行业id f2010062
//    private String adType;//广告类型 f2010063


    //创意特征
    private Long ideaId; // 创意ID f3010010
    //    private String buttonText; // 按钮文字 f3010020
//    private Integer iconH; // 创意图标高 f3010030
//    private Integer iconW; // 创意图标宽 f3010040
//    private Integer mjPicType; // 规格类型 f3010050
    private Integer ideaPicH1; // 创意图片高1 f3010060
    private Integer ideaPicW1; // 创意图片宽1 f3010070
    //    private Integer ideaPicH2; // 创意图片高2 f3010080
//    private Integer ideaPicW2; // 创意图片宽2 f3010090
//    private Integer ideaPicH3; // 创意图片高3 f3010100
//    private Integer ideaPicW3; // 创意图片宽3 f3010110
//    private Integer ideaPicNum; // 创意图片个数 f3010120
//    private String styleStandard; // 广告样式规格 f3010130
    private Integer ideaType; //互动创意类型(0-普通静态创意，1-动态创意) f3010140

    //创意素材标签特征
    private Long materialId; //素材ID
    private Integer pictureType; //素材图片类型（1=图片 3=视频）f3030000
    private List<AdxIdeaMaterialDo> pictureMaterialDo; //图片素材特征
    private List<AdxIdeaMaterialDo> videoMaterialDo; //视频素材特征

//    private String materialIndustryTag; // 素材行业标签
//    private String slotType; // 广告位性质
//    private String prizeElement; // 奖品元素
//    private String designColor; // 设计色调
//    private String designStyle; // 设计风格
//    private String textElement; // 文案元素
//    private String activityTool; // 活动工具


    private Long ideaUnitId; //创意素材ID

    //创意+分媒体行为特征
    private Long ideaAppExpCntDay; //创意+百度appId 当天曝光次数 f3060011
    private Long ideaAppClickCntDay; //创意+百度appId 当天点击次数 f3060012
    private Long ideaAppAdCostDay; //创意+百度appId 当天广告消耗	 f3060013

    private Long ideaAppLaunchCntDay; //创意+百度appId 当天发券次数 f3060016
    private Long ideaAppAdClickCntDay; //创意+百度appId 当天券点击次数 f3060017


    //上下文
    private String ua; // ua f4010010
    private String ip; // ip f4010020

    /**
     * IP应用场景 f4010021
     */
    private String ipUsageType;

    private Long areaCode; // 地域 f4010030
    //    private Integer deviceType; // 设备类型 f4010040
//    private Integer tuiaDeviceType; // 推啊平台的设备类型(标准) f4010041
    private String make; // 设备厂商 f4010050
    private String model; // 设备型号 f4010060
    private String os; // 操作系统 f4010070
    private String osv; // 操作系统版本
    private String carrier; // 运营商 f4010080
    //    private Integer connectionType; // 联网方式 f4010090
    private Integer tuiaConnectionType; // 推啊平台的联网方式(标准) f4010091
    //    private Float lat; // 纬度 f4010100
//    private Float lon; // 经度 f4010110
    private Long currentCreatTime; // 参与当前竞价请求的创建时间(时间戳) f4010120


    //用户行为
    private String gender; // 性别 f5010010
    //    private String interestKeyWords; // 用户兴趣 f5010020
    private String yob; // 出生年月 f5010030
    //    private Map<Long, Object> expTimeMap; // 该创意+设备号的当天累计曝光次数 f5010040
    private String imei; // 设备号 f5010050
    private Integer deviceRequestLevel; // 设备请求次数（1-当天首次进入 2-当天第二次进入 3-当天大于等于第三次进入）

    private Map<String, Long> imeiDayBidTimes; // 设备号 当天竞价次数  f5010060
    private Map<String, Long> imeiDayExpTimes; // 设备号 当天曝光次数  f5010070
    private Map<String, Long> resoDayBidTimes; // 资源位id+设备号 当天竞价次数  f5010080
    private Map<String, Long> resoDayExpTimes; // 资源位id+设备号 当天曝光次数  f5010090

    private String newSex; // (爱奇艺)性别标签 f5010100

    //上下文-新增
    private String appName; // 应用名称 f6010010
    private String appBundle; // 包名 f6010020
    //    private String appPageCat; // 应用当前页类型 f6010030
//    private Integer appPaid; // 0-免费 1-付费 f6010040
//    private String geoCountry; // 设备位置信息-国家 f6010050
//    private String geoRegion; // 设备位置信息-地区 f6010060
    private String geoCity; //设备位置信息-城市 f6010070
    //    private Integer geoType; //设备位置信息-定位类型 f6010080
    private String tagId; // adx资源位，竞价广告位ID（adx方） f6010090
    private Integer tagIndex; // adx资源位，竞价广告位顺序索引（adx方） f6010100
    private String pos; // 广告位位置，第几屏
    private String matType; // 流量需要的素材类型，图片,视频,原生之类的
//    private String appIndustryId; //app所属行业id f6010110

    //资源位+分媒体行为特征
    private Long resoAppExpCntDay; //资源位+百度appId  近1h曝光次数 f6060011
    private Long resoAppClickCntDay; //资源位+百度appId  近1h点击次数 f6060012
    private Long resoAppAdCostDay; //资源位+百度appId  近1h广告消耗 f6060013

    //资源位历史行为特征 放到了AdxStatsDo下面
    //private Long resoExpDay; // 资源位 当天 入口素材曝光次数 f3016010
    //private Long resoActAccDay; // 资源位 当天 活动访问次数 f3016011
    //private Long resoActJoinDay; // 资源位 当天 活动参与次数 f3016012
    //private Long resoCoupClkpvDay; // 资源位 当天 券计费点击次数 f3016013
    //private Long resoExp1Day; // 资源位 历史1天 入口素材曝光次数 f3016014
    //private Long resoActAcc1Day; // 资源位 历史1天 活动访问次数 f3016015
    //private Long resoActJoin1Day; // 资源位 历史1天 活动参与次数 f3016016
    //private Long resoCoupClkpv1Day; // 资源位 历史1天 券计费点击次数 f3016017
    //private Long resoExp7Day; // 资源位 历史7天 入口素材曝光次数 f3016018
    //private Long resoActAcc7Day; // 资源位 历史7天 活动访问次数 f3016019
    //private Long resoActJoin7Day; // 资源位 历史7天 活动参与次数 f3016020
    //private Long resoCoupClkpv7Day; // 资源位 历史7天 券计费点击次数 f3016021
    //private Long resoExp14Day; // 资源位 历史14天 入口素材曝光次数 f3016022
    //private Long resoActAcc14Day; // 资源位 历史14天 活动访问次数 f3016023
    //private Long resoActJoin14Day; // 资源位 历史14天 活动参与次数 f3016024
    //private Long resoCoupClkpv14Day; // 资源位 历史14天 券计费点击次数 f3016025




    // DMP数据引入
    private String userTagsList; //f7010010, 用户标签列表
    private String appList; //f7020010, app安装列表
    //    private String messageNameList; //f7030010, 短信签名列表
    //dmp特征加工
    private DmpFeature dmpFeature;

    //adx用户素材行为数据
//    private String expDayMaterials; //用户当天曝光的素材序列（曝光降序）TOP30
//    private String clickDayMaterials; //用户当天点击的素材序列（点击降序）TOP30
//    private String expWeekMaterials; //用户近7天曝光的素材序列 (曝光降序) TOP30
//    private String clickWeekMaterials; //用户近7天点击的素材序列（点击降序）TOP30
//    private String resoExpDayMaterials; //用户+资源位，当天曝光的素材序列（曝光降序）TOP30
//    private String resoClickDayMaterials; //用户+资源位，当天点击的素材序列（点击降序）TOP30
//    private Long lastExpMaterialId; //用户+资源位，上次曝光的素材id
//    private Long lastClickMaterialId; //用户+资源位，上次点击的素材id


    //adx特定数据特征
//    private AiQiYiFeature aiQiYiFeature;//爱奇艺数据特征
    private MgTvFeature mgTvFeature;//芒果tv数据特征
//    private BaiDuFeature baiDuFeature;//百度联盟数据特征

    //PD特征
    private Integer pmpType; //0-RTB 1-PD 2-PDB f3020000
    private Long dealId; // PD deal ID f3020010
    private Long price; // PD ldeal出价 f3020020

    //创意+活动特征
    private Long ideaActAccCntDay;   //创意 当天活动访问次数 f3010141
    private Long ideaActJoinCntDay;   //创意 当天活动参与次数 f3010142
    private Long ideaActAccCntWeek;   //创意 一周活动访问次数 f3010143
    private Long ideaActJoinCntWeek;   //创意 一周活动参与次数 f3010144


    //素材行为数据
    private Long matAdxExpDay;  //创意素材 当天入口曝光次数 f3040010
    private Long matAdxClickDay;    //创意素材 当天入口点击次数 f3040020

//    private Long matAdxExp1d; //素材 历史1天 入口曝光次数 f3040030
//    private Long matAdxClick1d; //素材 历史1天 入口点击次数 f3040040
//    private Long matAdxExp7d; //素材 历史7天 入口曝光次数 f3040050
//    private Long matAdxClick7d; //素材 历史7天 入口点击次数 f3040060
//    private Long matAdxExp14d; //素材 历史14天 入口曝光次数 f3040070
//    private Long matAdxClick14d; //素材 历史14天 入口曝光次数 f3040080

    private Long matActReqDay;   //素材 当天活动访问次数
    private Long matActJoinDay;   //素材 当天活动参与次数
    private Long matAdvertExpDay;   //素材 当天广告曝光次数
    private Long matAdvertClkDay;   //素材 当天广告点击次数


    private Long matActReq7d;   //素材 7天活动访问次数
    private Long matActJoin7d;   //素材 7天活动参与次数
    private Long matAdvertExp7d;   //素材 7天广告曝光次数
    private Long matAdvertClk7d;   //素材 7天广告点击次数

    private Long matActReq28d;   //素材 28天活动访问次数
    private Long matActJoin28d;   //素材 28天活动参与次数
    private Long matAdvertExp28d;   //素材 28天广告曝光次数
    private Long matAdvertClk28d;   //素材 28天广告点击次数

    private Long matResoActReqDay;   //素材+资源位 当天活动访问次数
    private Long matResoActJoinDay;   //素材+资源位 当天活动参与次数
    private Long matResoAdvertExpDay;   //素材+资源位 当天广告曝光次数
    private Long matResoAdvertClkDay;   //素材+资源位 当天广告点击次数

    private Long matResoActReq7d;   //素材+资源位 7天活动访问次数
    private Long matResoActJoin7d;   //素材+资源位 7天活动参与次数
    private Long matResoAdvertExp7d;   //素材+资源位 7天广告曝光次数
    private Long matResoAdvertClk7d;   //素材+资源位 7天广告点击次数

    private Long matResoActReq28d;   //素材+资源位 28天活动访问次数
    private Long matResoActJoin28d;   //素材+资源位 28天活动参与次数
    private Long matResoAdvertExp28d;   //素材+资源位 28天广告曝光次数
    private Long matResoAdvertClk28d;   //素材+资源位 28天广告点击次数

//    private Map<Long, Long> matAdvertTradeExp7d; //素材 7天内不同广告行业券曝光次数
//    private Map<Long, Long> matAdvertTradeClk7d; //素材 7天内不同广告行业券点击次数
//    private Map<Long, Long> matAdvertTradeExp28d; //素材 28天内不同广告行业券曝光次数
//    private Map<Long, Long> matAdvertTradeClk28d; //素材 28天内不同广告行业券点击次数
//
//    private Map<Long, Long> matResoAdvertTradeExp7d; //素材+资源位 7天内不同广告行业券曝光次数
//    private Map<Long, Long> matResoAdvertTradeClk7d; //素材+资源位 7天内不同广告行业券点击次数
//    private Map<Long, Long> matResoAdvertTradeExp28d; //素材+资源位 28天内不同广告行业券曝光次数
//    private Map<Long, Long> matResoAdvertTradeClk28d; //素材+资源位 28天内不同广告行业券点击次数

    //活动+创意行为数据
    private Map<Long, Long> actIdeaActAccCntDay;    //活动+创意 当天活动访问数据
    private Map<Long, Long> actIdeaActJoinCntDay;    //活动+创意 当天活动参与数据
    private Map<Long, Long> actIdeaActAccCntWeek;    //活动+创意 一周活动访问数据
    private Map<Long, Long> actIdeaActJoinCntWeek;    //活动+创意 一周活动参与数据

    //计划维度、2d时间维度统计数据
    private Long idea2dExp;
    private Long idea2dClick;
    private Long idea2dFlcClick;


    //rta用户打分模型特征
    private RtaFeatureDo rtaFeatureDo;
}
